.. include:: quickstart/index.rst

Contents:

.. toctree::
   :caption: Quick Start
   :maxdepth: 3

   quickstart/index

.. toctree::
   :caption: Guides
   :maxdepth: 3

   guides/user/index
   guides/writer/index
   guides/contributor/index

.. toctree::
   :caption: Avocado Plugins
   :maxdepth: 3

   plugins/index

.. toctree::
   :caption: Our Releases
   :maxdepth: 3

   releases/index

.. toctree::
   :caption: Blueprints
   :titlesonly:

   blueprints/BP000
   blueprints/BP001
   blueprints/BP002
   blueprints/BP003

.. toctree::
   :caption: Learn More
   :maxdepth: 3

   misc/index

.. toctree::
   :caption: Configuration Reference
   :maxdepth: 3

   config/index


========
Test API
========

.. toctree::
   :caption: API Reference
   :maxdepth: 3

   api/test/avocado
   api/core/avocado.core
   api/utils/avocado.utils
   api/plugins/avocado.plugins
   api/optional-plugins/index

Indices and tables
==================
 
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. .. toctree::
..    :caption: API Reference
..    :hidden:
..    :maxdepth: 3
.. 
..    Avocado Tests API Reference <api/tests/index.rst>
..    Avocado Libraries API Reference <api/utils/index.rst>
..    Avocado (core) API Reference <api/core/index.rst>

.. .. toctree::
..    :maxdepth: 1
.. 
..    api/test/avocado.rst
..    api/utils/avocado.utils.rst
..    api/core/avocado.core.rst
..    api/plugins/avocado.plugins.rst
..    api/optional-plugins/index.rst
.. 
.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`

.. _TAP: https://testanything.org/
